<template>
  <div>
    <el-dialog
      width="60%"
      :title="`${title}设备扩展配置`"
      :visible="visible"
      :before-close="handleClose"
      custom-class="bbsl-location-dialog" :close-on-click-modal="false"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="120px"
      >
        <el-collapse accordion v-model="activeCollapse" class="form-collapse">
          <el-collapse-item name="1">
            <template slot="title">
              <span class="collapse-title">
                <i class="collapse-title-icon el-icon-info"></i>
                设备扩展信息
              </span>
            </template>
            <el-row>
              <el-col :span="12">
                <el-form-item prop="code" label="属性编码">
                  <el-input
                    maxlength="32"
                    placeholder="请输入属性编码(英文字母)"
                    @input="inputCode"
                    clearable
                    v-model="params.code"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="12">
                <el-form-item prop="name" label="属性名称">
                  <el-input
                    maxlength="64"
                    placeholder="请输入属性名称"
                    clearable
                    v-model="params.name"
                  ></el-input>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row>
              <el-col :span="12">
                <el-form-item prop="layout" label="布局">
                  <el-input
                    @input="Layout"
                    placeholder="请输入布局(小于25数字)"
                    clearable
                    v-model="params.layout"
                  >
                  </el-input>
                </el-form-item>
              </el-col>
              <el-col :span="12">
                <el-form-item label="控件类型" prop="ctlType">
                  <el-select
                    v-model="params.ctlType"
                    clearable
                    style="width: 100%"
                    placeholder="请选择控件类型"
                    @change="changeCtl"
                  >
                    <el-option
                      v-for="item in kjlxList"
                      :key="item.value"
                      :label="item.name"
                      :value="item.value"
                    ></el-option>
                  </el-select>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row>
              <el-col :span="12">
                <el-form-item prop="isRequired" label="是否必填">
                  <el-radio-group v-model="params.isRequired">
                    <el-radio :label="1">是</el-radio>
                    <el-radio :label="0">否</el-radio>
                  </el-radio-group>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row
              v-if="
                params.ctlType == 'checkbox' ||
                params.ctlType == 'select' ||
                params.ctlType == 'radio'
              "
            >
              <el-col :span="24">
                <el-form-item label="可选项" prop="json">
                  <el-table :data="dialogData" border style="width: 100%">
                    <el-table-column label="名称">
                      <template slot-scope="scope">
                        <el-input v-model="scope.row.label"></el-input>
                      </template>
                    </el-table-column>
                    <el-table-column label="值">
                      <template slot-scope="scope">
                        <el-input
                          v-model="scope.row.value"
                          onkeyup="value=value.replace(/[^\w\.\/]/ig,'')"
                        ></el-input>
                      </template>
                    </el-table-column>
                    <el-table-column label="操作" width="150">
                      <template slot-scope="scope">
                        <div class="column-box">
                          <i
                            class="el-icon-circle-plus"
                            style="font-size: 20px"
                            @click="addTable"
                          ></i>
                          <i
                            class="el-icon-remove-outline"
                            style="font-size: 20px"
                            @click="removeTable(scope.$index)"
                          ></i>
                        </div>
                      </template>
                    </el-table-column>
                  </el-table>
                </el-form-item>
              </el-col>
            </el-row>
          </el-collapse-item>
        </el-collapse>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import resourceManage from '@/api/device/resourceManage.js'
import utils from '@/hotent-ui-util.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'EquipmentExtendInfoDialog',
  data() {
    return {
      activeCollapse: '1',
      visible: false,
      title: '新增',
      params: {
        code: '',
        name: '',
        ctlType: '',
        isRequired: 0,
        layout: null,
        json: '',
        productConfId: '',
        deviceId: ''
      },
      dialogData: [{}],
      dialogVisible: false,
      TypeList: [],
      kjlxList: [],
      row: {},
      companyType: [], //单位类型
      rules: {
        code: [
          {
            required: true,
            message: '请输入参数代码(英文字母)',
            trigger: 'blur'
          }
        ],
        name: [
          {
            required: true,
            message: '请输入参数名称',
            trigger: 'blur'
          }
        ],
        ctlType: [
          {
            required: true,
            message: '请选择控件类型',
            trigger: 'blur'
          }
        ],

        layout: [
          {
            required: true,
            message: '请输入布局(小于25数字)',
            trigger: 'blur'
          }
        ],
        json: [
          {
            required: true,
            message: '请输入可选项',
            trigger: 'change'
          }
        ]
      }
    }
  },
  created() {
    this.kjlxList = dictUtils.getDictItemsFromCache('kjlx')
  },
  methods: {
    changeType() {
      this.$forceUpdate()
    },
    add(row) {
      this.visible = true
      this.params.productConfId = row.productId
      this.params.deviceId = row.id
      this.dialogData = [{}]
    },
    edit(row) {
      console.log(row)
      this.row = row
      this.params = utils.deepClone(row)
      this.params.isRequired = Number(row.isRequired)
      this.visible = true
      this.title = '修改'
      console.log(row.json)
      if (row.json) {
        this.dialogData = JSON.parse(row.json)
      }
    },
    Layout() {
      if (this.params.layout < 25 || typeof this.params.layout == 'number') {
      } else {
        this.params.layout = ''
      }
    },
    inputCode() {
      this.params.code = this.params.code.replace(/[^a-zA-Z]/g, '')
    },
    changeCtl(val) {
      this.dialogData = [{}]
    },
    addTable() {
      this.dialogData.push({})
    },
    removeTable(index) {
      if (this.dialogData.length == 1) {
        this.params.json = ''
        this.dialogData = [{}]
      } else {
        this.dialogData.splice(index, 1)
      }
    },

    handleClose() {
      this.params = {
        code: '',
        name: '',
        ctlType: '',
        isRequired: 0,
        layout: null,
        json: '',
        productConfId: '',
        deviceId: ''
      }
      this.title = '新增'
      this.activeCollapse = '1'
      this.visible = false
    },
    handleSave() {
      // 找到导致重复的元素，ID
      // 将所有对象的ID重新组成数组
      let jsons = true
      let dtype = true
      if (this.dialogData[0].label || this.dialogData[0].value) {
        const label = this.dialogData.map((e) => {
          if (e.label == '' || typeof e.label == 'undefined') {
            dtype = false
            jsons = false
            this.$message({
              message: '名称不能为空',
              type: 'warning'
            })
          } else {
            return e.label
          }
        })
        const value = this.dialogData.map((v) => {
          if (v.value == '' || typeof v.value == 'undefined') {
            dtype = false
            jsons = false
            this.$message({
              message: '值不能为空',
              type: 'warning'
            })
          } else {
            return v.value
          }
        })
        if (dtype) {
          // 通过Set去除数组重复项
          const labelSet = new Set(label)
          const valueSet = new Set(value)
          // 比较两个数组的长度来判断是否存在重复项
          if ([...labelSet].length != label.length) {
            jsons = false
            this.$message({
              message: '存在相同名称',
              type: 'warning'
            })
          } else if ([...valueSet].length != value.length) {
            jsons = false
            this.$message({
              message: '存在相同值',
              type: 'warning'
            })
          } else if (
            [...labelSet].length === label.length &&
            [...valueSet].length === value.length
          ) {
            this.params.json = JSON.stringify(this.dialogData)
            jsons = true
            this.dialogVisible = false
          }
        }
      }
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          let method
          if (jsons) {
            if (this.title === '新增') {
              method = resourceManage.addExtend
            } else if (this.title === '修改') {
              method = resourceManage.editExtend
            }
            method(this.params, (response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: this.title + '成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.$parent.loadData(1)
              } else {
                this.$message.warning(response.message)
              }
            })
          }
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000
          })
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}

.column-box {
  color: #409eff;
  display: flex;
  justify-content: space-evenly;
}
</style>
